##################################################
#
# Plot solar altitude versus time.
# Command line argument m specified month number.
#
# Example usage (for March eclipse):
#
# python Altitude.py -m 3 
#
#################################################

import numpy as np
import matplotlib.pyplot as plt
import argparse
import sys

#############################
# Set up command line options
#############################
parser = argparse.ArgumentParser()
parser.add_argument('-m', type = int, default = 1, help = 'month number')

###########################
# Read command line options
###########################
args = parser.parse_args()
m    = args.m

############
# Test input
############
if m < 1 or m > 12:
    print 'Error: m must lie between 1 and 12'
    sys.exit(1)

#####################    
# Construct filenames
#####################
TrackCentralFiles = ['Output/Jan/TrackCentral.out',   'Output/Feb/TrackCentral.out',   'Output/Mar/TrackCentral.out',   'Output/Apr/TrackCentral.out',
                     'Output/May/TrackCentral.out',   'Output/Jun/TrackCentral.out',   'Output/Jul/TrackCentral.out',   'Output/Aug/TrackCentral.out',
                     'Output/Sep/TrackCentral.out',   'Output/Oct/TrackCentral.out',   'Output/Nov/TrackCentral.out',   'Output/Dec/TrackCentral.out']
TrackCentralFile = TrackCentralFiles[m-1]

########################
# Read central line data
########################
tt = []
aa = []
infile = open (TrackCentralFile, 'r')
for line in infile:
    words = line.split ()
    t = float (words[0])
    a = float (words[3])
    tt.append (t)
    aa.append (a)

############    
# Draw graph
############
plt.ylim    (0., 1.1*max(aa))
plt.plot    (tt, aa, lw = 2, color = "blue")
plt.axvline (x = 0., lw = 2, ls = 'dotted', color = "red")
plt.ylabel  ('Solar altitude (degree)', size = 'large')
plt.xlabel  ('t - t_central (hour)', size = 'large')
plt.show    ()
