// Magnitude.cpp

#include "Eclipse.h"

// ======================================================================
// Function to track points of given eclipse magnitude at maximum eclipse
// ======================================================================
void TrackMagnitude (double t0, double P1, double P4, 
		     char filename00[], char filename01[], char filename02[], char filename03[],
		     char filename04[], char filename05[], char filename06[], char filename07[],
		     char filename08[], char filename09[], char filename10[], char filename11[],
		     char filename12[], char filename13[], char filename14[], char filename15[],
		     char filename16[], char filename17[], char filename18[], char filename19[],
		     char filename20[], char filename21[], char filename22[], char filename23[])
{
  // ...............
  // Open data files
  // ...............
  FILE *file00 = OpenFile (filename00, "w");
  FILE *file01 = OpenFile (filename01, "w");
  FILE *file02 = OpenFile (filename02, "w");
  FILE *file03 = OpenFile (filename03, "w");
  FILE *file04 = OpenFile (filename04, "w");
  FILE *file05 = OpenFile (filename05, "w");
  FILE *file06 = OpenFile (filename06, "w");
  FILE *file07 = OpenFile (filename07, "w");
  FILE *file08 = OpenFile (filename08, "w");
  FILE *file09 = OpenFile (filename09, "w");
  FILE *file10 = OpenFile (filename10, "w");
  FILE *file11 = OpenFile (filename11, "w");
  FILE *file12 = OpenFile (filename12, "w");
  FILE *file13 = OpenFile (filename13, "w");
  FILE *file14 = OpenFile (filename14, "w");
  FILE *file15 = OpenFile (filename15, "w");
  FILE *file16 = OpenFile (filename16, "w");
  FILE *file17 = OpenFile (filename17, "w");
  FILE *file18 = OpenFile (filename18, "w");
  FILE *file19 = OpenFile (filename19, "w");
  FILE *file20 = OpenFile (filename20, "w");
  FILE *file21 = OpenFile (filename21, "w");
  FILE *file22 = OpenFile (filename22, "w");
  FILE *file23 = OpenFile (filename23, "w");
  
  // ......................................................................................
  // Calculate magnitude = 0 curves at I+1 equally spaced times between start and end times
  // ......................................................................................
  double Magnitude = 0.; int I = MAGNITUDE; double dt = 1./24./60./60.;

  GetMagnitudeCurves (t0, P1, P4, Magnitude, 0, I, dt/10., file11, file12, file00, file23);
  
  // .........................................................................................
  // Calculate magnitude = 0.2 curves at I+1 equally spaced times between start and end times
  // ........................................................................................
  Magnitude = 0.2; 

  GetMagnitudeCurves (t0, P1, P4, Magnitude, 0, I, dt, file10, file13, file01, file22);
 
  // .........................................................................................
  // Calculate magnitude = 0.4 curves at I+1 equally spaced times between start and end times
  // ........................................................................................
  Magnitude = 0.4; 

  GetMagnitudeCurves (t0, P1, P4, Magnitude, 0, I, dt, file09, file14, file02, file21);
  
  // .........................................................................................
  // Calculate magnitude = 0.6 curves at I+1 equally spaced times between start and end times
  // ........................................................................................
  Magnitude = 0.6;

  GetMagnitudeCurves (t0, P1, P4, Magnitude, 0, I, dt, file08, file15, file03, file20);
  
  // .........................................................................................
  // Calculate magnitude = 0.8 curves at I+1 equally spaced times between start and end times
  // ........................................................................................
  Magnitude = 0.8; 

  GetMagnitudeCurves (t0, P1, P4, Magnitude, 0, I, dt, file07, file16, file04, file19);

  // ............................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced times between start and end times
  // ............................................................................................
  Magnitude = 1.; 

  GetMagnitudeCurves (t0, P1, P4, Magnitude, 1, I, dt, file06, file17, file05, file18);
  
  // ................
  // Close data files
  // ................
  fclose (file00); fclose (file01); fclose (file02); fclose (file03); fclose (file04); fclose (file05);
  fclose (file06); fclose (file07); fclose (file08); fclose (file09); fclose (file10); fclose (file11);
  fclose (file12); fclose (file13); fclose (file14); fclose (file15); fclose (file16); fclose (file17);
  fclose (file18); fclose (file19); fclose (file20); fclose (file21); fclose (file22); fclose (file23);
}

// ===================================================================
// Function to calculate magnitude = maximum curves at fixed magnitude
//
// magnitude = Magnitude on curves
// flag1 = 1/0 for maximum possible magnitude curves
//
// ===================================================================
void GetMagnitudeCurves (double t0, double P1, double P4, double Magnitude, int flag1, int I, double dt,
			 FILE *file00, FILE *file01, FILE *file02, FILE *file03)
{
  // ................
  // Upper left curve
  // ................
  GetMagnitudeCurve (P1, P4, t0, P1, Magnitude, 1, flag1, I, dt, file00);
 
  // .................
  // Upper right curve
  // .................
  GetMagnitudeCurve (P1, P4, t0, P4, Magnitude, 1, flag1, I, dt, file01);
   
  // ................
  // Lower left curve
  // ................
  GetMagnitudeCurve (P1, P4, t0, P1, Magnitude, 0, flag1, I, dt, file02);
 
  // .................
  // Lower right curve
  // .................
  GetMagnitudeCurve (P1, P4, t0, P4, Magnitude, 0, flag1, I, dt, file03);
}

// ==================================================================
// Function to calculate magnitude = maximum curve at fixed magnitude
//
// maximum magnitude = Magnitude on curve
// flag1 = 1/0 for maximum possible magnitude curve
// flag  = 1/0 for upper/lower curve
//
// ==================================================================
void GetMagnitudeCurve (double P1, double P4, double tstart, double tend, double Magnitude, int flag, int flag1, int I, double dt, FILE *file)
{
  int iter;
  double alpha, R, B, zeta, phi, lambda, xi, eta;
  double alpha_old, R_old, B_old, xi_old, eta_old;
  double phi_old, lambda_old, t_old;
  double phi_old_old, lambda_old_old, B_old_old;

  double sign;
  if (tend > tstart)
    sign = +1.;
  else
    sign = -1.;

  // Evenly spaced (in time) points
  int imax = -1; B = - 1.; B_old = -1.; B_old_old = -1.;
  for (int i = 0; i <= I; i++)
    {
      // Set time
      double t = tstart + (tend - tstart) * double (i) /double (I);
      
      // Get latitude and longitude
      GetMagnitudeLatitudeLongitude (t, Magnitude, flag, flag1, alpha, xi, eta, R, B, zeta, phi, lambda, iter);
      
      // Output data
      if (B > 0.)
	{
	  imax = i;
	  alpha_old = alpha; R_old = R; xi_old = xi; eta_old = eta;
	  B_old_old = B_old; phi_old_old = phi_old; lambda_old_old = lambda_old;
	  B_old     = B;     phi_old     = phi;     lambda_old     = lambda;
	  t_old     = t;        

	  fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
		   (180./M_PI) * phi, (180./M_PI) * lambda, (t-P1)/(P4-P1), B, R, alpha/M_PI, zeta, i, iter);
	}
    }

  // Finely spaced points close to B = 0
  if (imax > 0)
    {
      double t = tstart + (tend - tstart) * double (imax) /double (I);
      alpha = alpha_old; R = R_old; B = B_old; xi = xi_old; eta = eta_old;

      do
	{
	  // Set time
	  t += sign * dt;
	  
	  // Get latitude and longitude
	  GetMagnitudeLatitudeLongitude (t, Magnitude, flag, flag1, alpha, xi, eta, R, B, zeta, phi, lambda, iter);
	  
	  // Output data
	  if (B > 0.)
	    {
	      B_old_old = B_old; phi_old_old = phi_old; lambda_old_old = lambda_old;
	      B_old     = B;     phi_old     = phi;     lambda_old     = lambda;
	      t_old     = t;        

	      fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
		       (180./M_PI) * phi, (180./M_PI) * lambda, (t-P1)/(P4-P1), B, R, alpha/M_PI, zeta, -imax, iter);
	    }
	}
      while (B > 0.);
    }

  // Extrapolate to B = 0
  if (B_old_old > 0.)
    {
      double dBdt      = (B_old      - B_old_old)      /(sign * dt);
      double dphidt    = (phi_old    - phi_old_old)    /(sign * dt);
      double dlambdadt = (lambda_old - lambda_old_old) /(sign * dt);
      
      double DT = - B_old /dBdt;
      double t  = t_old + DT;
      B         = B_old      + dBdt      * DT;
      phi       = phi_old    + dphidt    * DT;
      lambda    = lambda_old + dlambdadt * DT;

      if (fabs (phi) < M_PI/2. && fabs (lambda) < 2.*M_PI)
	fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
		 (180./M_PI) * phi, (180./M_PI) * lambda, (t-P1)/(P4-P1), B, R, alpha/M_PI, zeta, -imax-1, iter);
    }
}

//===============================================================================================================
// Function to calculate latitude and longitude of given eclipse magnitude curve at given time at maximum eclipse
//
// flag  = 1/0 for upper/lower curve
// flag1 = 1/0 for maximum possible magnitude curves
//
//===============================================================================================================
void GetMagnitudeLatitudeLongitude (double t, double Magnitude, int flag, int flag1,
				    double &alpha, double &xi, double &eta, double &R, double &B, double &zeta, double &phi, double &lambda,
				    int &iter)
{
  // Get Besselian elements
  double x, y, d, f1, f2, l1, l2, mu;
  GetBesselElements (t, x, y, d, f1, f2, l1, l2, mu);
  
  // Get derivatives of Besselian elements
  double xdot, ydot, mudot, ddot, l1dot, l2dot;
  GetBesselElementDerivatives (t, xdot, ydot, mudot, ddot, l1dot, l2dot);
  
  double u, H, L1, L2;

  // Calculate initial alpha, eta, and xi if previous values not converged
  if (!(B > 0.) || !(R > 0.))
    {
      // Set radial distance from center line
      if (flag1)
	{
	  if (l2 < 0.)
	    R = - l2;
	  else
	    R = l2;
	}
      else
	R = l1 - Magnitude * (l1 + l2);

      // Calculate orientation angle
      if (flag)
	alpha = atan2 (xdot, -ydot);
      else
	alpha = atan2 (xdot, -ydot) + M_PI;

      // Calculate coordinates in fundamental system
      xi  = x + R * cos (alpha);
      eta = y + R * sin (alpha);
    }
 
  // Get initial zeta
  GetZeta (xi, eta, d, B, zeta);

  // Get initial L1 and L2
  GetL1L2 (f1, f2, l1, l2, zeta, L1, L2);
  
  // Iterate to take into account variation in L1 and L2
  double zeta_old;
  for (int j = 0; j < MAXZ; j++)
    {
      // Calculate time derivatives
      double xidot   = mudot * (zeta * cos (d) - eta * sin (d));
      double etadot  =   mudot * xi * sin (d) - ddot * zeta;
      double zetadot = - mudot * xi * cos (d) + ddot * eta;
      
      double L1dot = l1dot - zetadot * tan (f1);
      double L2dot = l2dot - zetadot * tan (f2);
      
      double udot = xidot  - xdot;
      double vdot = etadot - ydot;
      
      // Calculate orientation angle
      double S     = sqrt (udot*udot + vdot*vdot);
      double theta = atan2 (-udot, vdot);
      double fac   = (L1dot*L2 - L2dot*L1) /(L1 + L2) /S + R * (L1dot + L2dot) /(L1 + L2) /S;
      if (flag)
	alpha = theta + asin (fac);
      else
	alpha = theta + M_PI - asin (fac);

      // Get L1 and L2
      GetL1L2 (f1, f2, l1, l2, zeta, L1, L2);
      
      // Set radial distance from center line
      if (flag1)
	{
	  if (L2 < 0.)
	    R = - L2;
	  else
	    R = L2;
	}
      else
	R = L1 - Magnitude * (L1 + L2);
      
      // Calculate coordinates in fundamental system
      xi  = x + R * cos (alpha);
      eta = y + R * sin (alpha);
      
      // Calculate zeta
      zeta_old = zeta;
      GetZeta (xi, eta, d, B, zeta);

      iter = j;
      if (fabs (zeta_old - zeta) < TOLZ)
	break;
    }
    
  // Calculate latitude and longitude
  GetLatituteLongitude (xi, eta, d, mu, B, zeta, u, phi, H, lambda);
}
