#################################################
# Plot solar eclipse map.
# Command line argument m specified month number.
#
# Example usage (for March eclipse):
#
# python Map.py -m 3 
#
#################################################

from mpl_toolkits.basemap import Basemap
import numpy as np
import matplotlib.pyplot as plt
import argparse
import sys

#############################
# Set up command line options
#############################
parser = argparse.ArgumentParser()
parser.add_argument('-m', type = int, default = 1, help = 'month number')

###########################
# Read command line options
###########################
args = parser.parse_args()
m    = args.m

############
# Test input
############
if m < 1 or m > 12:
    print 'Error: m must lie between 1 and 12'
    sys.exit(1)

#####################
# Construct filenames
#####################
GreatestFiles = ['Output/Jan/Greatest.out', 'Output/Feb/Greatest.out', 'Output/Mar/Greatest.out', 'Output/Apr/Greatest.out',
                 'Output/May/Greatest.out', 'Output/Jun/Greatest.out', 'Output/Jul/Greatest.out', 'Output/Aug/Greatest.out',
                 'Output/Sep/Greatest.out', 'Output/Oct/Greatest.out', 'Output/Nov/Greatest.out', 'Output/Dec/Greatest.out']
TrackCentralFiles = ['Output/Jan/TrackCentral.out', 'Output/Feb/TrackCentral.out', 'Output/Mar/TrackCentral.out', 'Output/Apr/TrackCentral.out',
                     'Output/May/TrackCentral.out', 'Output/Jun/TrackCentral.out', 'Output/Jul/TrackCentral.out', 'Output/Aug/TrackCentral.out',
                     'Output/Sep/TrackCentral.out', 'Output/Oct/TrackCentral.out', 'Output/Nov/TrackCentral.out', 'Output/Dec/TrackCentral.out']
UmbralShadowFiles = ['Output/Jan/UmbralShadow.out', 'Output/Feb/UmbralShadow.out', 'Output/Mar/UmbralShadow.out', 'Output/Apr/UmbralShadow.out',
                     'Output/May/UmbralShadow.out', 'Output/Jun/UmbralShadow.out', 'Output/Jul/UmbralShadow.out', 'Output/Aug/UmbralShadow.out',
                     'Output/Sep/UmbralShadow.out', 'Output/Oct/UmbralShadow.out', 'Output/Nov/UmbralShadow.out', 'Output/Dec/UmbralShadow.out']
P1234Files = ['Output/Jan/P1234.out', 'Output/Feb/P1234.out', 'Output/Mar/P1234.out', 'Output/Apr/P1234.out',
              'Output/May/P1234.out', 'Output/Jun/P1234.out', 'Output/Jul/P1234.out', 'Output/Aug/P1234.out',
              'Output/Sep/P1234.out', 'Output/Oct/P1234.out', 'Output/Nov/P1234.out', 'Output/Dec/P1234.out']
PenumbralContact1Files = ['Output/Jan/PenumbralContact/1.out', 'Output/Feb/PenumbralContact/1.out', 'Output/Mar/PenumbralContact/1.out', 'Output/Apr/PenumbralContact/1.out',
                          'Output/May/PenumbralContact/1.out', 'Output/Jun/PenumbralContact/1.out', 'Output/Jul/PenumbralContact/1.out', 'Output/Aug/PenumbralContact/1.out',
                          'Output/Sep/PenumbralContact/1.out', 'Output/Oct/PenumbralContact/1.out', 'Output/Nov/PenumbralContact/1.out', 'Output/Dec/PenumbralContact/1.out']
PenumbralContact2Files = ['Output/Jan/PenumbralContact/2.out', 'Output/Feb/PenumbralContact/2.out', 'Output/Mar/PenumbralContact/2.out', 'Output/Apr/PenumbralContact/2.out',
                          'Output/May/PenumbralContact/2.out', 'Output/Jun/PenumbralContact/2.out', 'Output/Jul/PenumbralContact/2.out', 'Output/Aug/PenumbralContact/2.out',
                          'Output/Sep/PenumbralContact/2.out', 'Output/Oct/PenumbralContact/2.out', 'Output/Nov/PenumbralContact/2.out', 'Output/Dec/PenumbralContact/2.out']
Magnitude00Files = ['Output/Jan/Magnitude/00.out', 'Output/Feb/Magnitude/00.out', 'Output/Mar/Magnitude/00.out', 'Output/Apr/Magnitude/00.out',
                    'Output/May/Magnitude/00.out', 'Output/Jun/Magnitude/00.out', 'Output/Jul/Magnitude/00.out', 'Output/Aug/Magnitude/00.out',
                    'Output/Sep/Magnitude/00.out', 'Output/Oct/Magnitude/00.out', 'Output/Nov/Magnitude/00.out', 'Output/Dec/Magnitude/00.out']
Magnitude01Files = ['Output/Jan/Magnitude/01.out', 'Output/Feb/Magnitude/01.out', 'Output/Mar/Magnitude/01.out', 'Output/Apr/Magnitude/01.out',
                    'Output/May/Magnitude/01.out', 'Output/Jun/Magnitude/01.out', 'Output/Jul/Magnitude/01.out', 'Output/Aug/Magnitude/01.out',
                    'Output/Sep/Magnitude/01.out', 'Output/Oct/Magnitude/01.out', 'Output/Nov/Magnitude/01.out', 'Output/Dec/Magnitude/01.out']
Magnitude02Files = ['Output/Jan/Magnitude/02.out', 'Output/Feb/Magnitude/02.out', 'Output/Mar/Magnitude/02.out', 'Output/Apr/Magnitude/02.out',
                    'Output/May/Magnitude/02.out', 'Output/Jun/Magnitude/02.out', 'Output/Jul/Magnitude/02.out', 'Output/Aug/Magnitude/02.out',
                    'Output/Sep/Magnitude/02.out', 'Output/Oct/Magnitude/02.out', 'Output/Nov/Magnitude/02.out', 'Output/Dec/Magnitude/02.out']
Magnitude03Files = ['Output/Jan/Magnitude/03.out', 'Output/Feb/Magnitude/03.out', 'Output/Mar/Magnitude/03.out', 'Output/Apr/Magnitude/03.out',
                    'Output/May/Magnitude/03.out', 'Output/Jun/Magnitude/03.out', 'Output/Jul/Magnitude/03.out', 'Output/Aug/Magnitude/03.out',
                    'Output/Sep/Magnitude/03.out', 'Output/Oct/Magnitude/03.out', 'Output/Nov/Magnitude/03.out', 'Output/Dec/Magnitude/03.out']
Magnitude04Files = ['Output/Jan/Magnitude/04.out', 'Output/Feb/Magnitude/04.out', 'Output/Mar/Magnitude/04.out', 'Output/Apr/Magnitude/04.out',
                    'Output/May/Magnitude/04.out', 'Output/Jun/Magnitude/04.out', 'Output/Jul/Magnitude/04.out', 'Output/Aug/Magnitude/04.out',
                    'Output/Sep/Magnitude/04.out', 'Output/Oct/Magnitude/04.out', 'Output/Nov/Magnitude/04.out', 'Output/Dec/Magnitude/04.out']
Magnitude05Files = ['Output/Jan/Magnitude/05.out', 'Output/Feb/Magnitude/05.out', 'Output/Mar/Magnitude/05.out', 'Output/Apr/Magnitude/05.out',
                    'Output/May/Magnitude/05.out', 'Output/Jun/Magnitude/05.out', 'Output/Jul/Magnitude/05.out', 'Output/Aug/Magnitude/05.out',
                    'Output/Sep/Magnitude/05.out', 'Output/Oct/Magnitude/05.out', 'Output/Nov/Magnitude/05.out', 'Output/Dec/Magnitude/05.out']
Magnitude06Files = ['Output/Jan/Magnitude/06.out', 'Output/Feb/Magnitude/06.out', 'Output/Mar/Magnitude/06.out', 'Output/Apr/Magnitude/06.out',
                    'Output/May/Magnitude/06.out', 'Output/Jun/Magnitude/06.out', 'Output/Jul/Magnitude/06.out', 'Output/Aug/Magnitude/06.out',
                    'Output/Sep/Magnitude/06.out', 'Output/Oct/Magnitude/06.out', 'Output/Nov/Magnitude/06.out', 'Output/Dec/Magnitude/06.out']
Magnitude07Files = ['Output/Jan/Magnitude/07.out', 'Output/Feb/Magnitude/07.out', 'Output/Mar/Magnitude/07.out', 'Output/Apr/Magnitude/07.out',
                    'Output/May/Magnitude/07.out', 'Output/Jun/Magnitude/07.out', 'Output/Jul/Magnitude/07.out', 'Output/Aug/Magnitude/07.out',
                    'Output/Sep/Magnitude/07.out', 'Output/Oct/Magnitude/07.out', 'Output/Nov/Magnitude/07.out', 'Output/Dec/Magnitude/07.out']
Magnitude08Files = ['Output/Jan/Magnitude/08.out', 'Output/Feb/Magnitude/08.out', 'Output/Mar/Magnitude/08.out', 'Output/Apr/Magnitude/08.out',
                    'Output/May/Magnitude/08.out', 'Output/Jun/Magnitude/08.out', 'Output/Jul/Magnitude/08.out', 'Output/Aug/Magnitude/08.out',
                    'Output/Sep/Magnitude/08.out', 'Output/Oct/Magnitude/08.out', 'Output/Nov/Magnitude/08.out', 'Output/Dec/Magnitude/08.out']
Magnitude09Files = ['Output/Jan/Magnitude/09.out', 'Output/Feb/Magnitude/09.out', 'Output/Mar/Magnitude/09.out', 'Output/Apr/Magnitude/09.out',
                    'Output/May/Magnitude/09.out', 'Output/Jun/Magnitude/09.out', 'Output/Jul/Magnitude/09.out', 'Output/Aug/Magnitude/09.out',
                    'Output/Sep/Magnitude/09.out', 'Output/Oct/Magnitude/09.out', 'Output/Nov/Magnitude/09.out', 'Output/Dec/Magnitude/09.out']
Magnitude10Files = ['Output/Jan/Magnitude/10.out', 'Output/Feb/Magnitude/10.out', 'Output/Mar/Magnitude/10.out', 'Output/Apr/Magnitude/10.out',
                    'Output/May/Magnitude/10.out', 'Output/Jun/Magnitude/10.out', 'Output/Jul/Magnitude/10.out', 'Output/Aug/Magnitude/10.out',
                    'Output/Sep/Magnitude/10.out', 'Output/Oct/Magnitude/10.out', 'Output/Nov/Magnitude/10.out', 'Output/Dec/Magnitude/10.out']
Magnitude11Files = ['Output/Jan/Magnitude/11.out', 'Output/Feb/Magnitude/11.out', 'Output/Mar/Magnitude/11.out', 'Output/Apr/Magnitude/11.out',
                    'Output/May/Magnitude/11.out', 'Output/Jun/Magnitude/11.out', 'Output/Jul/Magnitude/11.out', 'Output/Aug/Magnitude/11.out',
                    'Output/Sep/Magnitude/11.out', 'Output/Oct/Magnitude/11.out', 'Output/Nov/Magnitude/11.out', 'Output/Dec/Magnitude/11.out']
Magnitude12Files = ['Output/Jan/Magnitude/12.out', 'Output/Feb/Magnitude/12.out', 'Output/Mar/Magnitude/12.out', 'Output/Apr/Magnitude/12.out',
                    'Output/May/Magnitude/12.out', 'Output/Jun/Magnitude/12.out', 'Output/Jul/Magnitude/12.out', 'Output/Aug/Magnitude/12.out',
                    'Output/Sep/Magnitude/12.out', 'Output/Oct/Magnitude/12.out', 'Output/Nov/Magnitude/12.out', 'Output/Dec/Magnitude/12.out']
Magnitude13Files = ['Output/Jan/Magnitude/13.out', 'Output/Feb/Magnitude/13.out', 'Output/Mar/Magnitude/13.out', 'Output/Apr/Magnitude/13.out',
                    'Output/May/Magnitude/13.out', 'Output/Jun/Magnitude/13.out', 'Output/Jul/Magnitude/13.out', 'Output/Aug/Magnitude/13.out',
                    'Output/Sep/Magnitude/13.out', 'Output/Oct/Magnitude/13.out', 'Output/Nov/Magnitude/13.out', 'Output/Dec/Magnitude/13.out']
Magnitude14Files = ['Output/Jan/Magnitude/14.out', 'Output/Feb/Magnitude/14.out', 'Output/Mar/Magnitude/14.out', 'Output/Apr/Magnitude/14.out',
                    'Output/May/Magnitude/14.out', 'Output/Jun/Magnitude/14.out', 'Output/Jul/Magnitude/14.out', 'Output/Aug/Magnitude/14.out',
                    'Output/Sep/Magnitude/14.out', 'Output/Oct/Magnitude/14.out', 'Output/Nov/Magnitude/14.out', 'Output/Dec/Magnitude/14.out']
Magnitude15Files = ['Output/Jan/Magnitude/15.out', 'Output/Feb/Magnitude/15.out', 'Output/Mar/Magnitude/15.out', 'Output/Apr/Magnitude/15.out',
                    'Output/May/Magnitude/15.out', 'Output/Jun/Magnitude/15.out', 'Output/Jul/Magnitude/15.out', 'Output/Aug/Magnitude/15.out',
                    'Output/Sep/Magnitude/15.out', 'Output/Oct/Magnitude/15.out', 'Output/Nov/Magnitude/15.out', 'Output/Dec/Magnitude/15.out']
Magnitude16Files = ['Output/Jan/Magnitude/16.out', 'Output/Feb/Magnitude/16.out', 'Output/Mar/Magnitude/16.out', 'Output/Apr/Magnitude/16.out',
                    'Output/May/Magnitude/16.out', 'Output/Jun/Magnitude/16.out', 'Output/Jul/Magnitude/16.out', 'Output/Aug/Magnitude/16.out',
                    'Output/Sep/Magnitude/16.out', 'Output/Oct/Magnitude/16.out', 'Output/Nov/Magnitude/16.out', 'Output/Dec/Magnitude/16.out']
Magnitude17Files = ['Output/Jan/Magnitude/17.out', 'Output/Feb/Magnitude/17.out', 'Output/Mar/Magnitude/17.out', 'Output/Apr/Magnitude/17.out',
                    'Output/May/Magnitude/17.out', 'Output/Jun/Magnitude/17.out', 'Output/Jul/Magnitude/17.out', 'Output/Aug/Magnitude/17.out',
                    'Output/Sep/Magnitude/17.out', 'Output/Oct/Magnitude/17.out', 'Output/Nov/Magnitude/17.out', 'Output/Dec/Magnitude/17.out']
Magnitude18Files = ['Output/Jan/Magnitude/18.out', 'Output/Feb/Magnitude/18.out', 'Output/Mar/Magnitude/18.out', 'Output/Apr/Magnitude/18.out',
                    'Output/May/Magnitude/18.out', 'Output/Jun/Magnitude/18.out', 'Output/Jul/Magnitude/18.out', 'Output/Aug/Magnitude/18.out',
                    'Output/Sep/Magnitude/18.out', 'Output/Oct/Magnitude/18.out', 'Output/Nov/Magnitude/18.out', 'Output/Dec/Magnitude/18.out']
Magnitude19Files = ['Output/Jan/Magnitude/19.out', 'Output/Feb/Magnitude/19.out', 'Output/Mar/Magnitude/19.out', 'Output/Apr/Magnitude/19.out',
                    'Output/May/Magnitude/19.out', 'Output/Jun/Magnitude/19.out', 'Output/Jul/Magnitude/19.out', 'Output/Aug/Magnitude/19.out',
                    'Output/Sep/Magnitude/19.out', 'Output/Oct/Magnitude/19.out', 'Output/Nov/Magnitude/19.out', 'Output/Dec/Magnitude/19.out']
Magnitude20Files = ['Output/Jan/Magnitude/20.out', 'Output/Feb/Magnitude/20.out', 'Output/Mar/Magnitude/20.out', 'Output/Apr/Magnitude/20.out',
                    'Output/May/Magnitude/20.out', 'Output/Jun/Magnitude/20.out', 'Output/Jul/Magnitude/20.out', 'Output/Aug/Magnitude/20.out',
                    'Output/Sep/Magnitude/20.out', 'Output/Oct/Magnitude/20.out', 'Output/Nov/Magnitude/20.out', 'Output/Dec/Magnitude/20.out']
Magnitude21Files = ['Output/Jan/Magnitude/21.out', 'Output/Feb/Magnitude/21.out', 'Output/Mar/Magnitude/21.out', 'Output/Apr/Magnitude/21.out',
                    'Output/May/Magnitude/21.out', 'Output/Jun/Magnitude/21.out', 'Output/Jul/Magnitude/21.out', 'Output/Aug/Magnitude/21.out',
                    'Output/Sep/Magnitude/21.out', 'Output/Oct/Magnitude/21.out', 'Output/Nov/Magnitude/21.out', 'Output/Dec/Magnitude/21.out']
Magnitude22Files = ['Output/Jan/Magnitude/22.out', 'Output/Feb/Magnitude/22.out', 'Output/Mar/Magnitude/22.out', 'Output/Apr/Magnitude/22.out',
                    'Output/May/Magnitude/22.out', 'Output/Jun/Magnitude/22.out', 'Output/Jul/Magnitude/22.out', 'Output/Aug/Magnitude/22.out',
                    'Output/Sep/Magnitude/22.out', 'Output/Oct/Magnitude/22.out', 'Output/Nov/Magnitude/22.out', 'Output/Dec/Magnitude/22.out']
Magnitude23Files = ['Output/Jan/Magnitude/23.out', 'Output/Feb/Magnitude/23.out', 'Output/Mar/Magnitude/23.out', 'Output/Apr/Magnitude/23.out',
                    'Output/May/Magnitude/23.out', 'Output/Jun/Magnitude/23.out', 'Output/Jul/Magnitude/23.out', 'Output/Aug/Magnitude/23.out',
                    'Output/Sep/Magnitude/23.out', 'Output/Oct/Magnitude/23.out', 'Output/Nov/Magnitude/23.out', 'Output/Dec/Magnitude/23.out']
Maximum00Files = ['Output/Jan/Maximum/00.out', 'Output/Feb/Maximum/00.out', 'Output/Mar/Maximum/00.out', 'Output/Apr/Maximum/00.out',
                  'Output/May/Maximum/00.out', 'Output/Jun/Maximum/00.out', 'Output/Jul/Maximum/00.out', 'Output/Aug/Maximum/00.out',
                  'Output/Sep/Maximum/00.out', 'Output/Oct/Maximum/00.out', 'Output/Nov/Maximum/00.out', 'Output/Dec/Maximum/00.out']
Maximum01Files = ['Output/Jan/Maximum/01.out', 'Output/Feb/Maximum/01.out', 'Output/Mar/Maximum/01.out', 'Output/Apr/Maximum/01.out',
                  'Output/May/Maximum/01.out', 'Output/Jun/Maximum/01.out', 'Output/Jul/Maximum/01.out', 'Output/Aug/Maximum/01.out',
                  'Output/Sep/Maximum/01.out', 'Output/Oct/Maximum/01.out', 'Output/Nov/Maximum/01.out', 'Output/Dec/Maximum/01.out']
Maximum02Files = ['Output/Jan/Maximum/02.out', 'Output/Feb/Maximum/02.out', 'Output/Mar/Maximum/02.out', 'Output/Apr/Maximum/02.out',
                  'Output/May/Maximum/02.out', 'Output/Jun/Maximum/02.out', 'Output/Jul/Maximum/02.out', 'Output/Aug/Maximum/02.out',
                  'Output/Sep/Maximum/02.out', 'Output/Oct/Maximum/02.out', 'Output/Nov/Maximum/02.out', 'Output/Dec/Maximum/02.out']
Maximum03Files = ['Output/Jan/Maximum/03.out', 'Output/Feb/Maximum/03.out', 'Output/Mar/Maximum/03.out', 'Output/Apr/Maximum/03.out',
                  'Output/May/Maximum/03.out', 'Output/Jun/Maximum/03.out', 'Output/Jul/Maximum/03.out', 'Output/Aug/Maximum/03.out',
                  'Output/Sep/Maximum/03.out', 'Output/Oct/Maximum/03.out', 'Output/Nov/Maximum/03.out', 'Output/Dec/Maximum/03.out']
Maximum04Files = ['Output/Jan/Maximum/04.out', 'Output/Feb/Maximum/04.out', 'Output/Mar/Maximum/04.out', 'Output/Apr/Maximum/04.out',
                  'Output/May/Maximum/04.out', 'Output/Jun/Maximum/04.out', 'Output/Jul/Maximum/04.out', 'Output/Aug/Maximum/04.out',
                  'Output/Sep/Maximum/04.out', 'Output/Oct/Maximum/04.out', 'Output/Nov/Maximum/04.out', 'Output/Dec/Maximum/04.out']
Maximum05Files = ['Output/Jan/Maximum/05.out', 'Output/Feb/Maximum/05.out', 'Output/Mar/Maximum/05.out', 'Output/Apr/Maximum/05.out',
                  'Output/May/Maximum/05.out', 'Output/Jun/Maximum/05.out', 'Output/Jul/Maximum/05.out', 'Output/Aug/Maximum/05.out',
                  'Output/Sep/Maximum/05.out', 'Output/Oct/Maximum/05.out', 'Output/Nov/Maximum/05.out', 'Output/Dec/Maximum/05.out']
Maximum06Files = ['Output/Jan/Maximum/06.out', 'Output/Feb/Maximum/06.out', 'Output/Mar/Maximum/06.out', 'Output/Apr/Maximum/06.out',
                  'Output/May/Maximum/06.out', 'Output/Jun/Maximum/06.out', 'Output/Jul/Maximum/06.out', 'Output/Aug/Maximum/06.out',
                  'Output/Sep/Maximum/06.out', 'Output/Oct/Maximum/06.out', 'Output/Nov/Maximum/06.out', 'Output/Dec/Maximum/06.out']
Maximum07Files = ['Output/Jan/Maximum/07.out', 'Output/Feb/Maximum/07.out', 'Output/Mar/Maximum/07.out', 'Output/Apr/Maximum/07.out',
                  'Output/May/Maximum/07.out', 'Output/Jun/Maximum/07.out', 'Output/Jul/Maximum/07.out', 'Output/Aug/Maximum/07.out',
                  'Output/Sep/Maximum/07.out', 'Output/Oct/Maximum/07.out', 'Output/Nov/Maximum/07.out', 'Output/Dec/Maximum/07.out']
Maximum08Files = ['Output/Jan/Maximum/08.out', 'Output/Feb/Maximum/08.out', 'Output/Mar/Maximum/08.out', 'Output/Apr/Maximum/08.out',
                  'Output/May/Maximum/08.out', 'Output/Jun/Maximum/08.out', 'Output/Jul/Maximum/08.out', 'Output/Aug/Maximum/08.out',
                  'Output/Sep/Maximum/08.out', 'Output/Oct/Maximum/08.out', 'Output/Nov/Maximum/08.out', 'Output/Dec/Maximum/08.out']
Maximum09Files = ['Output/Jan/Maximum/09.out', 'Output/Feb/Maximum/09.out', 'Output/Mar/Maximum/09.out', 'Output/Apr/Maximum/09.out',
                  'Output/May/Maximum/09.out', 'Output/Jun/Maximum/09.out', 'Output/Jul/Maximum/09.out', 'Output/Aug/Maximum/09.out',
                  'Output/Sep/Maximum/09.out', 'Output/Oct/Maximum/09.out', 'Output/Nov/Maximum/09.out', 'Output/Dec/Maximum/09.out']
Maximum10Files = ['Output/Jan/Maximum/10.out', 'Output/Feb/Maximum/10.out', 'Output/Mar/Maximum/10.out', 'Output/Apr/Maximum/10.out',
                  'Output/May/Maximum/10.out', 'Output/Jun/Maximum/10.out', 'Output/Jul/Maximum/10.out', 'Output/Aug/Maximum/10.out',
                  'Output/Sep/Maximum/10.out', 'Output/Oct/Maximum/10.out', 'Output/Nov/Maximum/10.out', 'Output/Dec/Maximum/10.out']
Maximum11Files = ['Output/Jan/Maximum/11.out', 'Output/Feb/Maximum/11.out', 'Output/Mar/Maximum/11.out', 'Output/Apr/Maximum/11.out',
                  'Output/May/Maximum/11.out', 'Output/Jun/Maximum/11.out', 'Output/Jul/Maximum/11.out', 'Output/Aug/Maximum/11.out',
                  'Output/Sep/Maximum/11.out', 'Output/Oct/Maximum/11.out', 'Output/Nov/Maximum/11.out', 'Output/Dec/Maximum/11.out']
Maximum12Files = ['Output/Jan/Maximum/12.out', 'Output/Feb/Maximum/12.out', 'Output/Mar/Maximum/12.out', 'Output/Apr/Maximum/12.out',
                  'Output/May/Maximum/12.out', 'Output/Jun/Maximum/12.out', 'Output/Jul/Maximum/12.out', 'Output/Aug/Maximum/12.out',
                  'Output/Sep/Maximum/12.out', 'Output/Oct/Maximum/12.out', 'Output/Nov/Maximum/12.out', 'Output/Dec/Maximum/12.out']
Maximum13Files = ['Output/Jan/Maximum/13.out', 'Output/Feb/Maximum/13.out', 'Output/Mar/Maximum/13.out', 'Output/Apr/Maximum/13.out',
                  'Output/May/Maximum/13.out', 'Output/Jun/Maximum/13.out', 'Output/Jul/Maximum/13.out', 'Output/Aug/Maximum/13.out',
                  'Output/Sep/Maximum/13.out', 'Output/Oct/Maximum/13.out', 'Output/Nov/Maximum/13.out', 'Output/Dec/Maximum/13.out']
Maximum14Files = ['Output/Jan/Maximum/14.out', 'Output/Feb/Maximum/14.out', 'Output/Mar/Maximum/14.out', 'Output/Apr/Maximum/14.out',
                  'Output/May/Maximum/14.out', 'Output/Jun/Maximum/14.out', 'Output/Jul/Maximum/14.out', 'Output/Aug/Maximum/14.out',
                  'Output/Sep/Maximum/14.out', 'Output/Oct/Maximum/14.out', 'Output/Nov/Maximum/14.out', 'Output/Dec/Maximum/14.out']
Maximum15Files = ['Output/Jan/Maximum/15.out', 'Output/Feb/Maximum/15.out', 'Output/Mar/Maximum/15.out', 'Output/Apr/Maximum/15.out',
                  'Output/May/Maximum/15.out', 'Output/Jun/Maximum/15.out', 'Output/Jul/Maximum/15.out', 'Output/Aug/Maximum/15.out',
                  'Output/Sep/Maximum/15.out', 'Output/Oct/Maximum/15.out', 'Output/Nov/Maximum/15.out', 'Output/Dec/Maximum/15.out']
Maximum16Files = ['Output/Jan/Maximum/16.out', 'Output/Feb/Maximum/16.out', 'Output/Mar/Maximum/16.out', 'Output/Apr/Maximum/16.out',
                  'Output/May/Maximum/16.out', 'Output/Jun/Maximum/16.out', 'Output/Jul/Maximum/16.out', 'Output/Aug/Maximum/16.out',
                  'Output/Sep/Maximum/16.out', 'Output/Oct/Maximum/16.out', 'Output/Nov/Maximum/16.out', 'Output/Dec/Maximum/16.out']
Maximum17Files = ['Output/Jan/Maximum/17.out', 'Output/Feb/Maximum/17.out', 'Output/Mar/Maximum/17.out', 'Output/Apr/Maximum/17.out',
                  'Output/May/Maximum/17.out', 'Output/Jun/Maximum/17.out', 'Output/Jul/Maximum/17.out', 'Output/Aug/Maximum/17.out',
                  'Output/Sep/Maximum/17.out', 'Output/Oct/Maximum/17.out', 'Output/Nov/Maximum/17.out', 'Output/Dec/Maximum/17.out']

GreatestFile          = GreatestFiles[m-1]
TrackCentralFile      = TrackCentralFiles[m-1]
UmbralShadowFile      = UmbralShadowFiles[m-1]
P1234File             = P1234Files[m-1]
PenumbralContact1File = PenumbralContact1Files[m-1]
PenumbralContact2File = PenumbralContact2Files[m-1]
Magnitude00File       = Magnitude00Files[m-1]
Magnitude01File       = Magnitude01Files[m-1]
Magnitude02File       = Magnitude02Files[m-1]
Magnitude03File       = Magnitude03Files[m-1]
Magnitude04File       = Magnitude04Files[m-1]
Magnitude05File       = Magnitude05Files[m-1]
Magnitude06File       = Magnitude06Files[m-1]
Magnitude07File       = Magnitude07Files[m-1]
Magnitude08File       = Magnitude08Files[m-1]
Magnitude09File       = Magnitude09Files[m-1]
Magnitude10File       = Magnitude10Files[m-1]
Magnitude11File       = Magnitude11Files[m-1]
Magnitude12File       = Magnitude12Files[m-1]
Magnitude13File       = Magnitude13Files[m-1]
Magnitude14File       = Magnitude14Files[m-1]
Magnitude15File       = Magnitude15Files[m-1]
Magnitude16File       = Magnitude16Files[m-1]
Magnitude17File       = Magnitude17Files[m-1]
Magnitude18File       = Magnitude18Files[m-1]
Magnitude19File       = Magnitude19Files[m-1]
Magnitude20File       = Magnitude20Files[m-1]
Magnitude21File       = Magnitude21Files[m-1]
Magnitude22File       = Magnitude22Files[m-1]
Magnitude23File       = Magnitude23Files[m-1]
Maximum00File         = Maximum00Files[m-1]
Maximum01File         = Maximum01Files[m-1]
Maximum02File         = Maximum02Files[m-1]
Maximum03File         = Maximum03Files[m-1]
Maximum04File         = Maximum04Files[m-1]
Maximum05File         = Maximum05Files[m-1]
Maximum06File         = Maximum06Files[m-1]
Maximum07File         = Maximum07Files[m-1]
Maximum08File         = Maximum08Files[m-1]
Maximum09File         = Maximum09Files[m-1]
Maximum10File         = Maximum10Files[m-1]
Maximum11File         = Maximum11Files[m-1]
Maximum12File         = Maximum12Files[m-1]
Maximum13File         = Maximum13Files[m-1]
Maximum14File         = Maximum14Files[m-1]
Maximum15File         = Maximum15Files[m-1]
Maximum16File         = Maximum16Files[m-1]
Maximum17File         = Maximum17Files[m-1]

#######################################################
# lon_0, lat_0 are the center point of the projection,
# which corresponds to point of greatest eclipse.
#######################################################

###################
# Read lon_0, lat_0
###################
infile =   open (GreatestFile, 'r')
line   =   infile.readline ()
words  =   line.split ()
lat0   =   float (words[0])
lon0   = - float (words[1])
l20    =   float (words[2])
latc   =   float (words[3])
lonc   = - float (words[4])

if l20 > 0.:
    c = 'red'
else:
    c = 'yellow'

##########    
# Draw map
##########
m = Basemap (projection = 'ortho', lon_0 = lon0, lat_0 = lat0, resolution = 'l')

########################
# Read central line data
########################
llat = []
llon = []
infile = open (TrackCentralFile, 'r')
for line in infile:
    words =   line.split ()
    lat   =   float (words[1])
    lon   = - float (words[2])
    llat.append (lat)
    llon.append (lon)

################################
# Plot point of greatest eclipse
################################
m.plot (lonc, latc, color = 'black' , marker = '+', markersize = 15, latlon = 'true')
m.plot (lonc, latc, color = 'black' , marker = 'x', markersize = 10, latlon = 'true')

############################
# Plot P1, P2, P3, P4 points
############################
llat = []
llon = []
infile = open (P1234File, 'r')
for line in infile:
    words =   line.split ()
    lat   =   float (words[0])
    lon   = - float (words[1])
    llat.append (lat)
    llon.append (lon)

m.plot (llon, llat, 'm+', color = 'black',  markersize = 15, latlon = 'true')
m.plot (llon, llat, 'mx', color = 'black',  markersize = 10,  latlon = 'true')    

######################################
# Plot western penumbral contact curve
######################################
llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (PenumbralContact1File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    lat2  =   float (words[2])
    lon2  = - float (words[3])
    llat1.append (lat1)
    llon1.append (lon1)
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'magenta', linewidth = 2, latlon = 'true')
m.plot (llon2, llat2, color = 'magenta', linewidth = 2, latlon = 'true')

######################################
# Plot eastern penumbral contact curve
######################################
llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (PenumbralContact2File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    lat2  =   float (words[2])
    lon2  = - float (words[3])
    llat1.append (lat1)
    llon1.append (lon1)
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'magenta', linewidth = 2, latlon = 'true')
m.plot (llon2, llat2, color = 'magenta', linewidth = 2, latlon = 'true')

###################################################
# Plot maximum eclipse at constant magnitude curves
###################################################
llat3 = []
llon3 = []
llat4 = []
llon4 = []

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude00File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude01File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat3.append (llat1[-1])
    llon3.append (llon1[-1])
if len (llat2) > 0:
    llat3.append (llat2[-1])
    llon3.append (llon2[-1])
len0 = len (llat1)    

m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude02File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude03File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat3.append (llat1[-1])
    llon3.append (llon1[-1])
if len (llat2) > 0:
    llat3.append (llat2[-1])
    llon3.append (llon2[-1])    

m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')    

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude04File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude05File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat3.append (llat1[-1])
    llon3.append (llon1[-1])
if len (llat2) > 0:
    llat3.append (llat2[-1])
    llon3.append (llon2[-1])    

m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')    

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude06File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude07File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat3.append (llat1[-1])
    llon3.append (llon1[-1])
if len (llat2) > 0:
    llat3.append (llat2[-1])
    llon3.append (llon2[-1])    

m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')    

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude08File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude09File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat3.append (llat1[-1])
    llon3.append (llon1[-1])
if len (llat2) > 0:
    llat3.append (llat2[-1])
    llon3.append (llon2[-1])    
    
m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')    

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude10File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude11File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat3.append (llat1[-1])
    llon3.append (llon1[-1])
if len (llat2) > 0:
    llat3.append (llat2[-1])
    llon3.append (llon2[-1])
len11 = len (llat2)    

m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')    

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude12File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude13File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat4.append (llat1[-1])
    llon4.append (llon1[-1])
if len (llat2) > 0:
    llat4.append (llat2[-1])
    llon4.append (llon2[-1])
    
m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude14File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude15File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat4.append (llat1[-1])
    llon4.append (llon1[-1])
if len (llat2) > 0:
    llat4.append (llat2[-1])
    llon4.append (llon2[-1])    

m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude16File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude17File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat4.append (llat1[-1])
    llon4.append (llon1[-1])
if len (llat2) > 0:
    llat4.append (llat2[-1])
    llon4.append (llon2[-1])
    
m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude18File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude19File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len(llat1) > 0:
    llat4.append (llat1[-1])
    llon4.append (llon1[-1])
if len(llat2) > 0:
    llat4.append (llat2[-1])
    llon4.append (llon2[-1])
    
m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude20File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude21File, 'r')
for line in infile:
    words = line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat4.append (llat1[-1])
    llon4.append (llon1[-1])
if len (llat2) > 0:
    llat4.append (llat2[-1])
    llon4.append (llon2[-1])

m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')
    
llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Magnitude22File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Magnitude23File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)
if len (llat1) > 0:
    llat4.append (llat1[-1])
    llon4.append (llon1[-1])
if len (llat2) > 0:
    llat4.append (llat2[-1])
    llon4.append (llon2[-1])
    
m.plot (llon1, llat1, color = 'brown', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'brown', linewidth = 1.5, latlon = 'true')

##############################################    
# Plot maximum eclipse at constant time curves
##############################################
llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum00File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum01File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum02File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum03File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum04File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum05File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 2.0, linestyle = 'dashed', latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum06File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum07File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum08File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum09File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum10File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum11File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum12File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum13File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 2.0, linestyle = 'dashed', latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum14File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum15File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

llat1 = []
llon1 = []
llat2 = []
llon2 = []
infile = open (Maximum16File, 'r')
for line in infile:
    words =   line.split ()
    lat1  =   float (words[0])
    lon1  = - float (words[1])
    llat1.append (lat1)
    llon1.append (lon1)
infile = open (Maximum17File, 'r')
for line in infile:
    words =   line.split ()
    lat2  =   float (words[0])
    lon2  = - float (words[1])
    llat2.append (lat2)
    llon2.append (lon2)

m.plot (llon1, llat1, color = 'green', linewidth = 1.5, latlon = 'true')
m.plot (llon2, llat2, color = 'green', linewidth = 1.5, latlon = 'true')

#####################    
# Plot umbral shadows
#####################
llat = []
llon = []
infile = open (UmbralShadowFile, 'r')
for line in infile:
    words =   line.split ()
    lat   =   float (words[0])
    lon   = - float (words[1])
    llat.append (lat)
    llon.append (lon)

m.plot (llon, llat, '.', color = c, markersize = 2, latlon = 'true')

# ###############
# Draw landmasses
#################
m.drawcoastlines ()
m.drawcountries  ()
m.drawstates     ()
m.fillcontinents (color = 'white', lake_color = 'lightblue')

##############################
# Draw parallels and meridians
##############################
m.drawparallels (np.arange (-80., 80., 10.))
m.drawmeridians (np.arange (0., 360., 30.), latmax = 90)
m.drawmapboundary (fill_color = 'lightblue')

###########
# Show plot
###########
#plt.savefig('Eclipse.pdf')
plt.show()

