// Maximum.cpp

#include "Eclipse.h"

// ==========================================================
// Function to track points of maximum eclipse at given times
// ==========================================================
void TrackMaximum (double tc, double P1, double P4, double Mg, 
		   char filename00[], char filename01[],
		   char filename02[], char filename03[],
		   char filename04[], char filename05[],
		   char filename06[], char filename07[],
		   char filename08[], char filename09[],
		   char filename10[], char filename11[],
		   char filename12[], char filename13[],
		   char filename14[], char filename15[],
		   char filename16[], char filename17[])
{
  // ...............
  // Open data files
  // ...............
  FILE *file00 = OpenFile (filename00, "w");
  FILE *file01 = OpenFile (filename01, "w");
  FILE *file02 = OpenFile (filename02, "w");
  FILE *file03 = OpenFile (filename03, "w");
  FILE *file04 = OpenFile (filename04, "w");
  FILE *file05 = OpenFile (filename05, "w");
  FILE *file06 = OpenFile (filename06, "w");
  FILE *file07 = OpenFile (filename07, "w");
  FILE *file08 = OpenFile (filename08, "w");
  FILE *file09 = OpenFile (filename09, "w");
  FILE *file10 = OpenFile (filename10, "w");
  FILE *file11 = OpenFile (filename11, "w");
  FILE *file12 = OpenFile (filename12, "w");
  FILE *file13 = OpenFile (filename13, "w");
  FILE *file14 = OpenFile (filename14, "w");
  FILE *file15 = OpenFile (filename15, "w");
  FILE *file16 = OpenFile (filename16, "w");
  FILE *file17 = OpenFile (filename17, "w");

  // ..........................................
  // Ensure that maximum eclipse magnitude is 1
  // ..........................................
  if (Mg > 1.)
    Mg = 1.;

  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // minus 2 hours
  // .....................................................................................
  double t = tc - 2./24.; int I = MAXIMUM;

  GetMaximumCurves (t, Mg, I, file00, file09);

  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // minus 1.5 hours
  // .....................................................................................
  t = tc - 1.5/24.;

  GetMaximumCurves (t, Mg, I, file01, file10);

  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // minus 1 hour
  // .....................................................................................
  t = tc - 1./24.; 

  GetMaximumCurves (t, Mg, I, file02, file11);

  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // minus 1/2 hour
  // .....................................................................................
  t = tc - 0.5/24.;

  GetMaximumCurves (t, Mg, I, file03, file12);
  
  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // .....................................................................................
  t = tc; 

  GetMaximumCurves (t, Mg, I, file04, file13);
  
  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // plus 1/2 hour
  // .....................................................................................
  t = tc + 0.5/24.;

  GetMaximumCurves (t, Mg, I, file05, file14);
  
  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // plus 1 hour
  // .....................................................................................
  t = tc + 1./24.; 

  GetMaximumCurves (t, Mg, I, file06, file15);

  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // plus 1.5 hours
  // .....................................................................................
  t = tc + 1.5/24.;

  GetMaximumCurves (t, Mg, I, file07, file16);
  
  // .....................................................................................
  // Calculate magnitude = maximum curves at I+1 equally spaced magnitudes at central time
  // plus 2 hours
  // .....................................................................................
  t = tc + 2./24.; 

  GetMaximumCurves (t, Mg, I, file08, file17);
   
  // ................
  // Close data files
  // ................
  fclose (file00); fclose (file01); fclose (file02); fclose (file03);
  fclose (file04); fclose (file05); fclose (file06); fclose (file07);
  fclose (file08); fclose (file09); fclose (file10); fclose (file11);
  fclose (file12); fclose (file13); fclose (file14); fclose (file15);
  fclose (file16); fclose (file17);
}

// ==============================================================
// Function to calculate magnitude = maximum curves at fixed time
// ==============================================================
void GetMaximumCurves (double t, double Mg, int I, FILE *file00, FILE *file01)
{
  // ...........
  // Upper curve
  // ...........
  GetMaximumCurve (t, Mg, 1, I, file00);
 
  // ...........
  // Lower curve
  // ...........
  GetMaximumCurve (t, Mg, 0, I, file01);
}

// =============================================================
// Function to calculate magnitude = maximum curve at fixed time
//
// flag = 1/0 for upper/lower curve
//
// =============================================================
void GetMaximumCurve (double t, double Mg, int flag, int I, FILE *file)
{
  int iter;
  double alpha, R = -1., B = -1., zeta, phi, lambda, xi, eta, Magnitude;
  double alpha_old, R_old, B_old, xi_old, eta_old;
  double phi_old, lambda_old, M_old;
  double phi_old_old, lambda_old_old, B_old_old;

  Magnitude = Mg;
  GetMagnitudeLatitudeLongitude (t, Magnitude, flag, 0, alpha, xi, eta, R, B, zeta, phi, lambda, iter);

  if (B > 0.)
    {
      // Evenly spaced (in magnitude) points 
      int imax = -1; B_old = -1.; B_old_old = -1.;
      for (int i = 0; i <= I; i++)
	{
	  // Set magnitude
	  Magnitude = Mg * double (I-i) /double (I);
	  
	  // Get latitude and longitude
	  GetMagnitudeLatitudeLongitude (t, Magnitude, flag, 0, alpha, xi, eta, R, B, zeta, phi, lambda, iter);
	  
	  // Output data
	  if (B > 0. && R > 0.)
	    {
	      imax = i;
	      alpha_old = alpha; R_old = R; xi_old = xi; eta_old = eta;
	      B_old_old = B_old; phi_old_old = phi_old; lambda_old_old = lambda_old;
	      B_old     = B;     phi_old     = phi;     lambda_old     = lambda;
	      M_old     = Magnitude;        
	      
	      fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
		       (180./M_PI) * phi, (180./M_PI) * lambda, Magnitude/Mg, B, R, alpha/M_PI, zeta, i, iter);
	    }
	}

      // Finely spaced points close to B = 0
      double dM = - Mg /double(100*I);
      if (imax < I)
	{
	  Magnitude = Mg * double (I-imax) /double (I);
	  alpha = alpha_old; R = R_old; B = B_old; xi = xi_old; eta = eta_old;
	  
	  do
	    {
	      // Set magnitude
	      Magnitude += dM;
	      
	      // Get latitude and longitude
	      GetMagnitudeLatitudeLongitude (t, Magnitude, flag, 0, alpha, xi, eta, R, B, zeta, phi, lambda, iter);
	      
	      // Output data
	      if (B > 0.)
		{
		  B_old_old = B_old; phi_old_old = phi_old; lambda_old_old = lambda_old;
		  B_old     = B;     phi_old     = phi;     lambda_old     = lambda;
		  M_old     = Magnitude;        

		  fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
			   (180./M_PI) * phi, (180./M_PI) * lambda, Magnitude/Mg, B, R, alpha/M_PI, zeta, -imax, iter);
		}
	    }
	  while (B > 0.);
	}
      
      // Extrapolate to B = 0
      if (imax < I && B_old_old > 0.)
	{
	  double dBdM      = (B_old      - B_old_old)      /dM;
	  double dphidM    = (phi_old    - phi_old_old)    /dM;
	  double dlambdadM = (lambda_old - lambda_old_old) /dM;
	  
	  double DM = - B_old /dBdM;
	  Magnitude = M_old + DM;
	  B         = B_old      + dBdM      * DM;
	  phi       = phi_old    + dphidM    * DM;
	  lambda    = lambda_old + dlambdadM * DM;

	   if (fabs (phi) < M_PI/2. && fabs (lambda) < 2.*M_PI)
	     fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
		      (180./M_PI) * phi, (180./M_PI) * lambda, Magnitude/Mg, B, R, alpha/M_PI, zeta, -imax-1, iter);
	}
    }
  else
    {
      // Evenly spaced (in magnitude) points 
      int imax = -1; B = -1.; B_old = -1.; B_old_old = -1.;
      for (int i = 0; i <= I; i++)
	{
	  // Set magnitude
	  Magnitude = Mg * double (i) /double (I);
	  
	  // Get latitude and longitude
	  GetMagnitudeLatitudeLongitude (t, Magnitude, flag, 0, alpha, xi, eta, R, B, zeta, phi, lambda, iter);
	  
	  // Output data
	  if (B > 0. && R > 0.)
	    {
	      imax = i;
	      alpha_old = alpha; R_old = R; xi_old = xi; eta_old = eta;
	      B_old_old = B_old; phi_old_old = phi_old; lambda_old_old = lambda_old;
	      B_old     = B;     phi_old     = phi;     lambda_old     = lambda;
	      M_old     = Magnitude;
	      
	      fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
		       (180./M_PI) * phi, (180./M_PI) * lambda, Magnitude/Mg, B, R, alpha/M_PI, zeta, i, iter);
	    }
	}

      // Finely spaced points close to B = 0
      double dM = Mg /double(100*I);
      if (imax < I)
	{
	  Magnitude = Mg * double (imax) /double (I);
	  alpha = alpha_old; R = R_old; B = B_old; xi = xi_old; eta = eta_old;
	  
	  do
	    {
	      // Set magnitude
	      Magnitude += dM;
	      
	      // Get latitude and longitude
	      GetMagnitudeLatitudeLongitude (t, Magnitude, flag, 0, alpha, xi, eta, R, B, zeta, phi, lambda, iter);
	      
	      // Output data
	      if (B > 0.)
		{
		  B_old_old = B_old; phi_old_old = phi_old; lambda_old_old = lambda_old;
		  B_old     = B;     phi_old     = phi;     lambda_old     = lambda;
		  M_old     = Magnitude;        

		  fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
			   (180./M_PI) * phi, (180./M_PI) * lambda, Magnitude/Mg, B, R, alpha/M_PI, zeta, -imax, iter);
		}
	    }
	  while (B > 0.);
	}
      
      // Extrapolate to B = 0
      if (imax < I && B_old_old > 0.)
	{
	  double dBdM      = (B_old      - B_old_old)      /dM;
	  double dphidM    = (phi_old    - phi_old_old)    /dM;
	  double dlambdadM = (lambda_old - lambda_old_old) /dM;
	  
	  double DM = - B_old /dBdM;
	  Magnitude = M_old + DM;
	  B         = B_old      + dBdM      * DM;
	  phi       = phi_old    + dphidM    * DM;
	  lambda    = lambda_old + dlambdadM * DM;

	   if (fabs (phi) < M_PI/2. && fabs (lambda) < 2.*M_PI)
	     fprintf (file, "%e %e %e %e %e %e %e %d %d\n",
		      (180./M_PI) * phi, (180./M_PI) * lambda, Magnitude/Mg, B, R, alpha/M_PI, zeta, -imax-1, iter);
	} 
    }
}
