// Moon.cpp

#include "Eclipse.h"

// ==========================================================
// Function to return geocentric elongation of Moon from Sun.
// t is Julian day number. 
// ==========================================================
double MoonElongation (double t)
{
  // Get geocentric ecliptic coordinates of Sun
  double Sun_r, Sun_beta, Sun_lambda;
  SunEcliptic (t, Sun_r, Sun_beta, Sun_lambda, 1, 1, 1, 1);

  // Get geocentric ecliptic coordinates of Moon
  double Moon_r, Moon_beta, Moon_lambda;
  MoonEcliptic (t, Moon_r, Moon_beta, Moon_lambda, 1, 1, 1, 1);

  // Return geocentric elongation of Moon from Sun
  double E = Moon_lambda - Sun_lambda;
  return atan2 (sin (E), cos (E));
}

// ===========================================================
// Function to determine dates of all new moons in given year,
// and test for solar eclipses.
// Y is year (e.g., 1963).
// ===========================================================
void NewMoon (int Y)
{
  printf ("\n");
  int Y0 = Y;

  // Find initial lunar elongation from Sun
  int    M = 1;
  double D = 1.;
  double JD;
  DatetoJulian (Y, M, D, JD);
  double E = MoonElongation (JD);
  
  // Estimate date of first new moon
  if (E < 0.)
    JD += (-E) * (29.5306 /2. /M_PI);
  else
    JD += (2.*M_PI - E) * (29.5306 /(2. * M_PI));

  // Find actual dates of new moons
  for (int i = 0; i < 13; i++)
    {
      do
	{
	  E   = MoonElongation (JD);
	  JD -= E * (29.5306 /(2. * M_PI));
	}
      while (fabs (E) > 1.e-10);
      
      // Test for solar eclipse at new moon
      JuliantoDate (JD, Y, M, D);
      if (Y == Y0)
	TestEclipse (JD);
 
      JD += 29.5306;
    }
}
